package com.example.androidapplication

import android.app.AlertDialog
import android.os.Build
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.widget.ArrayAdapter
import android.widget.EditText
import android.widget.Toast
import androidx.annotation.RequiresApi
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.DividerItemDecoration
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.LinearLayoutManager
import com.example.androidapplication.databinding.ActivityCalendarBinding
import com.example.androidapplication.network.ApiService
import com.example.androidapplication.network.CalendarEvent
import com.example.androidapplication.network.CreateEventRequest
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext
import java.text.SimpleDateFormat
import java.time.Instant
import java.time.LocalDate
import java.time.ZoneId
import androidx.fragment.app.DialogFragment
import com.example.androidapplication.databinding.DialogNewEventBinding
import com.example.androidapplication.network.User
import com.example.androidapplication.network.UserData
import com.example.androidapplication.utils.SharedPreferencesHelper

import java.time.LocalDateTime
import java.time.format.DateTimeFormatter
import java.util.Date

fun LocalDateTime.toString(): String {
    return format(DateTimeFormatter.ISO_LOCAL_DATE_TIME)
}

fun String.toLocalDateTime(): LocalDateTime {
    return LocalDateTime.parse(this, DateTimeFormatter.ISO_LOCAL_DATE_TIME)
}

class CalendarActivity : AppCompatActivity() {
    private lateinit var binding: ActivityCalendarBinding
    private lateinit var adapter: CalendarAdapter
    private var currentUser: UserData? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityCalendarBinding.inflate(layoutInflater)
        setContentView(binding.root)

        currentUser = SharedPreferencesHelper.getUserData(this)

        setupToolbar()
        setupRecyclerView()
        loadEvents()
        setupFab()
    }

    private fun setupToolbar() {
//        binding.toolbar.toolbarTitle.text = "Calendrier"
    }

    private fun setupRecyclerView() {
        adapter = CalendarAdapter(emptyList()) { event ->
            // Gestion du clic sur un événement
            showEventDetails(event)
        }
        binding.eventsRecyclerView.apply {
            layoutManager = LinearLayoutManager(this@CalendarActivity)
            adapter = this@CalendarActivity.adapter
        }
    }

    private fun setupFab() {
        binding.fab.visibility = if (currentUser?.role == "admin") View.VISIBLE else View.GONE

        binding.fab.setOnClickListener {
            NewEventDialogFragment.newInstance { title, description, start, end ->
                createNewEvent(title, description, start, end)
            }.show(supportFragmentManager, "NewEvent")
        }
    }

    private fun createNewEvent(title: String, description: String, start: Date, end: Date) {
        CoroutineScope(Dispatchers.IO).launch {
            try {
                val request = CreateEventRequest(
                    title = title,
                    description = description,
                    start_date = start.toString(),
                    end_date = end.toString()
                )

                val response = ApiService.getInstance(this@CalendarActivity)
                    .createEvent(request)

                withContext(Dispatchers.Main) {
                    if (response.isSuccessful) {
                        loadEvents()
                        Toast.makeText(this@CalendarActivity,
                            "Événement créé",
                            Toast.LENGTH_SHORT).show()
                    } else {
                        Toast.makeText(this@CalendarActivity,
                            "Erreur: ${response.message()}",
                            Toast.LENGTH_SHORT).show()
                    }
                }
            } catch (e: Exception) {
                withContext(Dispatchers.Main) {
                    Toast.makeText(this@CalendarActivity,
                        "Erreur réseau: ${e.message}",
                        Toast.LENGTH_SHORT).show()
                }
            }
        }
    }

    private fun loadEvents() {
        CoroutineScope(Dispatchers.IO).launch {
            try {
                val events = ApiService.getInstance(this@CalendarActivity).getEvents()
                withContext(Dispatchers.Main) {
                    adapter.updateEvents(events)
                }
            } catch (e: Exception) {
                withContext(Dispatchers.Main) {
                    Toast.makeText(this@CalendarActivity, "Erreur de chargement", Toast.LENGTH_SHORT).show()
                }
            }
        }
    }

    private fun showEventDetails(event: CalendarEvent) {
        AlertDialog.Builder(this)
            .setTitle(event.title)
            .setMessage("""
                ${SimpleDateFormat("dd/MM/yyyy HH:mm").format(event.start_date)} - 
                ${SimpleDateFormat("HH:mm").format(event.end_date)}
                
                ${event.description}
            """.trimIndent())
            .setPositiveButton("OK", null)
            .show()
    }
}