package com.example.androidapplication

import android.app.AlertDialog
import android.content.Intent
import android.os.Bundle
import android.widget.EditText
import android.widget.Spinner
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.DividerItemDecoration
import androidx.recyclerview.widget.LinearLayoutManager
import com.example.androidapplication.databinding.ActivityUsersBinding
import com.example.androidapplication.network.ApiService
import com.example.androidapplication.network.Note
import com.example.androidapplication.utils.SharedPreferencesHelper
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext
import android.widget.ArrayAdapter
import com.example.androidapplication.CalendarActivity
import com.example.androidapplication.network.CreateEventRequest
import com.example.androidapplication.network.CreateUserRequest

class UsersActivity : AppCompatActivity() {
    private lateinit var binding: ActivityUsersBinding
    private lateinit var adapter: UsersAdapter
    private var isAdmin = false

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityUsersBinding.inflate(layoutInflater)
        setContentView(binding.root)

        checkAdminStatus()
        setupToolbar()
        setupRecyclerView()
        loadUsers()
        setupFab()
    }

    private fun checkAdminStatus() {
        isAdmin = SharedPreferencesHelper.getUserData(this)?.role == "admin"
        if (!isAdmin) finish() // Ferme l'activité si non-admin
    }

    private fun setupToolbar() {
//        binding.toolbar.toolbarTitle.text = "Gestion des utilisateurs"
//        binding.toolbar.homeButton.setOnClickListener { finish() }
    }

    private fun setupRecyclerView() {
        adapter = UsersAdapter(isAdmin) { userId ->
            showDeleteDialog(userId)
        }
        binding.usersRecyclerView.apply {
            layoutManager = LinearLayoutManager(this@UsersActivity)
            adapter = this@UsersActivity.adapter
            addItemDecoration(DividerItemDecoration(context, LinearLayoutManager.VERTICAL))
        }
    }

    private fun loadUsers() {
        CoroutineScope(Dispatchers.IO).launch {
            try {
                val users = ApiService.getInstance(this@UsersActivity).getUsers()
                withContext(Dispatchers.Main) {
                    adapter.submitList(users)
                }
            } catch (e: Exception) {
                withContext(Dispatchers.Main) {
                    Toast.makeText(this@UsersActivity, "Erreur de chargement", Toast.LENGTH_SHORT).show()
                }
            }
        }
    }

    private fun setupFab() {
        binding.fab.setOnClickListener {
            showCreateUserDialog()
        }
    }

    private fun showCreateUserDialog() {
        val dialogView = layoutInflater.inflate(R.layout.dialog_create_user, null)
        val emailInput = dialogView.findViewById<EditText>(R.id.emailInput)
        val usernameInput = dialogView.findViewById<EditText>(R.id.usernameInput)
        val passwordInput = dialogView.findViewById<EditText>(R.id.passwordInput)
        val roleSpinner = dialogView.findViewById<Spinner>(R.id.roleSpinner)

        // Configurez les options du Spinner
        val roles = arrayOf("user", "admin")
        val adapter = ArrayAdapter(
            this,
            android.R.layout.simple_spinner_item,
            roles
        ).apply {
            setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item)
        }
        roleSpinner.adapter = adapter

        AlertDialog.Builder(this)
            .setTitle("Nouvel utilisateur")
            .setView(dialogView)
            .setPositiveButton("Créer") { _, _ ->
                createUser(
                    emailInput.text.toString(),
                    usernameInput.text.toString(),
                    passwordInput.text.toString(),
                    roleSpinner.selectedItem.toString()
                )
            }
            .setNegativeButton("Annuler", null)
            .show()
    }

    private fun showDeleteDialog(userId: Int) {
        AlertDialog.Builder(this)
            .setTitle("Confirmation")
            .setMessage("Supprimer cet utilisateur ?")
            .setPositiveButton("Supprimer") { _, _ ->
                deleteUser(userId)
            }
            .setNegativeButton("Annuler", null)
            .show()
    }

    private fun createUser(email: String, username: String, password: String, role: String) {
        if (email.isBlank() || username.isBlank() || password.isBlank()) return

        CoroutineScope(Dispatchers.IO).launch {
            try {
                val request = CreateUserRequest(
                    email = email,
                    username = username,
                    password = password,
                    role = role
                )

                val response = ApiService.getInstance(this@UsersActivity)
                    .createUser(request)

                withContext(Dispatchers.Main) {
                    if (response.isSuccessful) {
                        loadUsers()
                        Toast.makeText(this@UsersActivity,
                            "Utilisateur créé",
                            Toast.LENGTH_SHORT).show()
                    } else {
                        Toast.makeText(this@UsersActivity,
                            "Erreur: ${response.message()}",
                            Toast.LENGTH_SHORT).show()
                    }
                }
            } catch (e: Exception) {
                withContext(Dispatchers.Main) {
                    Toast.makeText(this@UsersActivity, "Erreur: ${e.message}", Toast.LENGTH_SHORT).show()
                }
            }
        }
    }

    private fun deleteUser(userId: Int) {
        CoroutineScope(Dispatchers.IO).launch {
            try {
                ApiService.getInstance(this@UsersActivity).deleteUser(userId)
                withContext(Dispatchers.Main) {
                    loadUsers()
                    Toast.makeText(this@UsersActivity, "Utilisateur supprimé", Toast.LENGTH_SHORT).show()
                }
            } catch (e: Exception) {
                withContext(Dispatchers.Main) {
                    Toast.makeText(this@UsersActivity, "Erreur: ${e.message}", Toast.LENGTH_SHORT).show()
                }
            }
        }
    }
}